// ┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
// ┃ ██████ ██████ ██████       █      █      █      █      █ █▄  ▀███ █       ┃
// ┃ ▄▄▄▄▄█ █▄▄▄▄▄ ▄▄▄▄▄█  ▀▀▀▀▀█▀▀▀▀▀ █ ▀▀▀▀▀█ ████████▌▐███ ███▄  ▀█ █ ▀▀▀▀▀ ┃
// ┃ █▀▀▀▀▀ █▀▀▀▀▀ █▀██▀▀ ▄▄▄▄▄ █ ▄▄▄▄▄█ ▄▄▄▄▄█ ████████▌▐███ █████▄   █ ▄▄▄▄▄ ┃
// ┃ █      ██████ █  ▀█▄       █ ██████      █      ███▌▐███ ███████▄ █       ┃
// ┣━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┫
// ┃ Copyright (c) 2017, the Perspective Authors.                              ┃
// ┃ ╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌ ┃
// ┃ This file is part of the Perspective library, distributed under the terms ┃
// ┃ of the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0). ┃
// ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛

mod psp;

use std::fs;

use base64::prelude::*;
use regex::{Captures, Regex};

fn main() -> Result<(), std::io::Error> {
    let markdown = fs::read_to_string("./docs/lib.md")?;
    let markdown = Regex::new("<img src=\"(.+?)\"")
        .expect("regex")
        .replace_all(markdown.as_str(), |caps: &Captures| {
            let x = &caps[1];
            let svg = fs::read_to_string(format!("./docs/{}", x)).expect("svg");
            format!(
                "<img src=\"data:image/svg+xml;base64,{}\"",
                base64::prelude::BASE64_STANDARD.encode(svg)
            )
        });

    std::fs::write("docs/lib_gen.md", markdown.as_ref())?;
    if std::option_env!("PSP_DISABLE_CPP").is_none() {
        if let Some(artifact_dir) = psp::cmake_build()? {
            psp::cmake_link_deps(&artifact_dir)?;
        }
    }

    Ok(())
}
